@@ -322,6 +322,71 @@ ii<-ii+1
         }
 
                 }
+
+#Checar o Fator3
+if(pvalor[5]>sigF && pvalor[6]>sigF) {
+  cat('\nAnalizing the effect of the factor ',fac.names[3],'
+------------------------------------------------------------------------\n')
+  
+  i<-3 
+{
+  #Para os fatores QUALITATIVOS, teste de Tukey
+  if(quali[i]==TRUE && pvalor[i]<=sigF) {
+    cat(fac.names[i])
+    if(mcomp=='tukey'){
+      tukey(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='duncan'){
+      duncan(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='lsd'){
+      lsd(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='lsdb'){
+      lsdb(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='sk'){
+      scottknott(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='snk'){
+      snk(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=="ccboot"){
+      ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+#    if(mcomp=="ccf"){
+#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
+#    }
+  }
+  
+  if(quali[i]==TRUE && pvalor[i]>sigF) {
+    cat(fac.names[i])
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    mean.table<-tapply.stat(resp,fatores[,i],mean)
+    colnames(mean.table)<-c('Niveis','Medias')
+    print(mean.table)
+    cat('------------------------------------------------------------------------')
+  }
+  
+  #Para os fatores QUANTITATIVOS, regressao
+  if(quali[i]==FALSE && pvalor[i]<=sigF){
+    cat(fac.names[i])
+    reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
+  }
+  
+  if(quali[i]==FALSE && pvalor[i]>sigF) {
+    cat(fac.names[i])
+    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    mean.table<-tapply.stat(resp,fatores[,i],mean)
+    colnames(mean.table)<-c('Levels','Means')
+    print(mean.table)
+    cat('------------------------------------------------------------------------')
+  }
+  
+  cat('\n')
+}
+  
+}
 }
 
 #Interacao Fator1*Fator3
@@ -498,6 +563,71 @@ ii<-ii+1
         }
 
                 }
+
+#Checar o Fator2
+if(pvalor[4]>sigF && pvalor[6]>sigF) {
+  cat('\nAnalizing the effect of the factor ',fac.names[2],'
+------------------------------------------------------------------------\n')
+  
+  i<-2 
+{
+  #Para os fatores QUALITATIVOS, teste de Tukey
+  if(quali[i]==TRUE && pvalor[i]<=sigF) {
+    cat(fac.names[i])
+    if(mcomp=='tukey'){
+      tukey(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='duncan'){
+      duncan(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='lsd'){
+      lsd(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='lsdb'){
+      lsdb(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='sk'){
+      scottknott(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='snk'){
+      snk(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=="ccboot"){
+      ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+#    if(mcomp=="ccf"){
+#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
+#    }
+  }
+  
+  if(quali[i]==TRUE && pvalor[i]>sigF) {
+    cat(fac.names[i])
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    mean.table<-tapply.stat(resp,fatores[,i],mean)
+    colnames(mean.table)<-c('Niveis','Medias')
+    print(mean.table)
+    cat('------------------------------------------------------------------------')
+  }
+  
+  #Para os fatores QUANTITATIVOS, regressao
+  if(quali[i]==FALSE && pvalor[i]<=sigF){
+    cat(fac.names[i])
+    reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
+  }
+  
+  if(quali[i]==FALSE && pvalor[i]>sigF) {
+    cat(fac.names[i])
+    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    mean.table<-tapply.stat(resp,fatores[,i],mean)
+    colnames(mean.table)<-c('Levels','Means')
+    print(mean.table)
+    cat('------------------------------------------------------------------------')
+  }
+  
+  cat('\n')
+}
+  
+}
 }
 
 #Interacao Fator2*Fator3
@@ -674,6 +804,71 @@ ii<-ii+1
         }
 
                 }
+
+#Checar o Fator1
+if(pvalor[4]>sigF && pvalor[5]>sigF) {
+  cat('\nAnalizing the effect of the factor ',fac.names[1],'
+------------------------------------------------------------------------\n')
+  
+  i<-1
+{
+  #Para os fatores QUALITATIVOS, teste de Tukey
+  if(quali[i]==TRUE && pvalor[i]<=sigF) {
+    cat(fac.names[i])
+    if(mcomp=='tukey'){
+      tukey(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='duncan'){
+      duncan(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='lsd'){
+      lsd(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='lsdb'){
+      lsdb(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='sk'){
+      scottknott(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=='snk'){
+      snk(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+    if(mcomp=="ccboot"){
+      ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
+#    if(mcomp=="ccf"){
+#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
+#    }
+  }
+  
+  if(quali[i]==TRUE && pvalor[i]>sigF) {
+    cat(fac.names[i])
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    mean.table<-tapply.stat(resp,fatores[,i],mean)
+    colnames(mean.table)<-c('Niveis','Medias')
+    print(mean.table)
+    cat('------------------------------------------------------------------------')
+  }
+  
+  #Para os fatores QUANTITATIVOS, regressao
+  if(quali[i]==FALSE && pvalor[i]<=sigF){
+    cat(fac.names[i])
+    reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
+  }
+  
+  if(quali[i]==FALSE && pvalor[i]>sigF) {
+    cat(fac.names[i])
+    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    mean.table<-tapply.stat(resp,fatores[,i],mean)
+    colnames(mean.table)<-c('Levels','Means')
+    print(mean.table)
+    cat('------------------------------------------------------------------------')
+  }
+  
+  cat('\n')
+}
+  
+}
 }
 
 
